@@ -1,5 +1,5 @@
 # Run tests in local environment
 if (requireNamespace("tinytest", quietly = TRUE)) {
-  home <- length(unclass(packageVersion("pdp"))[[1]]) == 4
+  home <- tinytest::at_home()
   tinytest::test_package("pdp", at_home = home)
 }
